
delphin.edm
===========

.. automodule:: delphin.edm

This module provides the implementation of Elementary Dependency
Matching used by the :command:`edm` subcommand, which is the
recommended interface (see the :doc:`../guides/edm` guide for more
information). Only the :func:`compute` function is made available at
this time.

.. autofunction:: compute
